==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/include/bigfile_lib.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) die("Access Denied");		// [Security]Allow_url_fopen = On ?>
<?


// [2008-02-19] 뷮÷ ٿȽ/Ⱓ ʰó
function bigfile_expire($bigfile, $is_expire=true, $upload_dir='')
{
	global $TB, $G_SYS, $UPLOAD_ROOT, $UPLOAD_ROOT_NEW;

	if ($bigfile['bf_expire'] != 'Y')
	{
		if (!$is_expire)
		{
			// Ῡ ˻
			$limit_date = date('Y-m-d', (strtotime($bigfile['bf_regdate'])+(86400*($G_SYS[UPLOAD_MAIL_BIGFILE_DAY]-1))));
			if ($bigfile['bf_down'] >= $G_SYS[UPLOAD_MAIL_BIGFILE_COUNT] || date('Y-m-d') > $limit_date)
			{
				$is_expire = true;
			} else
			{
				return false;
			}	// if()
		}	// if()

		$sql = "
			UPDATE
				".$TB['BIGFILE']."
			SET
				bf_expire='Y'
			WHERE
				bf_key='" . $bigfile['bf_key'] . "'
				AND m_no='" . $bigfile['m_no'] . "'
			";
		db_query($sql);

		if ($bigfile['bf_type'] == 'B')
		{
			// file del - 뷮 ÷, ٿε Ƚ/Ⱓ ʰϿ   츦 Ͽ  Ҷ .
				if ($upload_dir == '')
				{
					$q = "SELECT m_id, m_mail_file_group FROM ".$TB['MEMBER']." WHERE m_no='".$bigfile['m_no']."'";
					$mbr = db_get_row($q);
					$upload_dir = 'bigfile/'.$G_SYS[MAIL_DOMAIN].'/'.$mbr['m_mail_file_group'].'/'.$mbr['m_id'];
				}	// if()
				$UPLOAD_ROOT_ORI = $UPLOAD_ROOT;
				$UPLOAD_ROOT = $UPLOAD_ROOT_NEW;

				if (file_exists($UPLOAD_ROOT.'/'.$upload_dir.'/'.$bigfile['bf_key']))
				{
					require_once("include/file.php");
					$errorMsg = file_del($bigfile['bf_key'], '', $upload_dir);
					if ($errorMsg)
						errorlog("뷮 ÷   Ͽϴ.\n=> " . $UPLOAD_ROOT . '/' . $upload_dir . '/' . $bigfile['bf_key'] . $errorMsg, 'FILE');

					require_once('include/member_size_lib.php');
					member_size_update($bigfile['m_no'], 'BIGFILE', -($bigfile['bf_size']));
				}	// if()

				$UPLOAD_ROOT = $UPLOAD_ROOT_ORI;
		}	// if()
	}	// if()

	return true;
}	// function()


// [2008-02-19] ӽ ε 丮 3ð   ڵ .
// bigfile_upload_tmp_del($UPLOAD_DIR[BIGFILE_TMP]);
function bigfile_upload_tmp_del($upload_dir)
{
	global $G_SYS, $UPLOAD_ROOT, $UPLOAD_ROOT_NEW;

	$G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'];

	$UPLOAD_ROOT_ORI = $UPLOAD_ROOT;
	$UPLOAD_ROOT = $UPLOAD_ROOT_NEW;

	$tmpdir = $UPLOAD_ROOT_NEW.'/'.$upload_dir;

	//   ð
	if ($G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'])
		$G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'] = 3;
	$del_time = (time() - ($G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR']*3600));

	if (is_dir($tmpdir))
	{
		$files = array();
		if ($dh = opendir($tmpdir)) {
			while (($file = readdir($dh)) !== false) {
				if ($file!="." && $file!=".." && is_file($tmpdir.'/'.$file) && filemtime($tmpdir.'/'.$file) <= $del_time)
				{
					$errorMsg = file_del($file, "", $upload_dir);
					if ($errorMsg)
						errorlog("ӽ ε   Ͽϴ.\n=> " . $tmpdir. '/' . $file . $errorMsg, 'FILE');
				}
			}
			closedir($dh);
		} else
		{
			errorlog("ӽ ε 丮 ۹̼ ߸Ǿ ڵ  Ͽϴ.\n=> " . $tmpdir, 'FILE');
		}	// if()
	}	// if()

	$UPLOAD_ROOT = $UPLOAD_ROOT_ORI;
}	// function()


?>

==> nmail-php-patch-2.6.1-to-2.6.12.tgz: nmail/include/bigfile_lib.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) die("Access Denied");		// [Security]Allow_url_fopen = On ?>
<?


// [2008-02-19] 뷮÷ ٿȽ/Ⱓ ʰó
function bigfile_expire($bigfile, $is_expire=true, $upload_dir='')
{
	global $TB, $G_SYS, $UPLOAD_ROOT, $UPLOAD_ROOT_NEW;

	if ($bigfile['bf_expire'] != 'Y')
	{
		if ($upload_dir == '')
		{
			$q = "SELECT m_id, m_mail_file_group, d_no FROM ".$TB['MEMBER']." WHERE m_no='".$bigfile['m_no']."'";
			$mbr = db_get_row($q);
			$upload_dir = 'bigfile/'.get_d_name($mbr['d_no']).'/'.$mbr['m_mail_file_group'].'/'.$mbr['m_id'];
		}	// if()
		$UPLOAD_ROOT_ORI = $UPLOAD_ROOT;
		$UPLOAD_ROOT = $UPLOAD_ROOT_NEW;
		if (!$is_expire)
		{
			// Ῡ ˻
			$limit_date = date('Y-m-d', (strtotime($bigfile['bf_regdate'])+(86400*($G_SYS[UPLOAD_MAIL_BIGFILE_DAY]-1))));
			if ($bigfile['bf_down'] >= $G_SYS[UPLOAD_MAIL_BIGFILE_COUNT] || date('Y-m-d') > $limit_date)
			{
				$is_expire = true;
			} else if ($bigfile['bf_expire'] == 'Y')
			{
				$is_expire = true;
			} else if (!file_exists($UPLOAD_ROOT.'/'.$upload_dir.'/'.$bigfile['bf_key']))		// [2014-05-28]    ,  ó.
			{
				$is_expire = true;
			} else
			{
				return false;
			}	// if()
		}	// if()

		$sql = "
			UPDATE
				".$TB['BIGFILE']."
			SET
				bf_expire='Y'
			WHERE
				bf_key='" . $bigfile['bf_key'] . "'
				AND m_no='" . $bigfile['m_no'] . "'
			";
		db_query($sql);

		if ($bigfile['bf_type'] == 'B')
		{
			// file del - 뷮 ÷, ٿε Ƚ/Ⱓ ʰϿ   츦 Ͽ  Ҷ .
				if (file_exists($UPLOAD_ROOT.'/'.$upload_dir.'/'.$bigfile['bf_key']))
				{
					require_once("include/file.php");
					$errorMsg = file_del($bigfile['bf_key'], '', $upload_dir);
					if ($errorMsg)
						errorlog("뷮 ÷   Ͽϴ.\n=> " . $UPLOAD_ROOT . '/' . $upload_dir . '/' . $bigfile['bf_key'] . $errorMsg, 'FILE');

					require_once('include/member_size_lib.php');
					member_size_update($bigfile['m_no'], 'BIGFILE', -($bigfile['bf_size']));
				}	// if()
		}	// if()

		$UPLOAD_ROOT = $UPLOAD_ROOT_ORI;
	} else
	{
		$is_expire = true;
	}	// if()

	return $is_expire;
}	// function()


// [2008-02-19] ӽ ε 丮 3ð   ڵ .
// bigfile_upload_tmp_del($UPLOAD_DIR[BIGFILE_TMP]);
function bigfile_upload_tmp_del($upload_dir)
{
	global $G_SYS, $UPLOAD_ROOT, $UPLOAD_ROOT_NEW;

	$G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'];

	$UPLOAD_ROOT_ORI = $UPLOAD_ROOT;
	$UPLOAD_ROOT = $UPLOAD_ROOT_NEW;

	$tmpdir = $UPLOAD_ROOT_NEW.'/'.$upload_dir;

	//   ð
	if ($G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'])
		$G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR'] = 3;

	$del_time = (time() - ($G_SYS['BIGFILE_UPLOAD_TMP_DEL_HOUR']*3600));

	if (is_dir($tmpdir))
	{
		// [2008-06-04]   ӽ 丮 
		if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
		{
			$cmd_rm = 'rmdir/q/s';
		} else
		{
			$cmd_rm = 'rm -rf';
		}	// if()

		// [2009-06-09] ӽ 丮   ذ
		require_once("include/file.php");

		$files = array();
		if ($dh = opendir($tmpdir)) {
			while (($file = readdir($dh)) !== false) {
				if ($file!="." && $file!=".." && is_file($tmpdir.'/'.$file) && filemtime($tmpdir.'/'.$file) <= $del_time)
				{
					$errorMsg = file_del($file, "", $upload_dir);
					if ($errorMsg)
						errorlog("ӽ ε   Ͽϴ.\n=> " . $tmpdir. '/' . $file . $errorMsg, 'FILE');
				} else if (strpos($file, 'NmailRestore_') !== false && is_dir($tmpdir.'/'.$file) && filemtime($tmpdir.'/'.$file) <= $del_time)
				{
					// [2008-06-04]   ӽ 丮 
					if ($tmpdir != '' && strpos($file, 'NmailRestore_') !== false)		// α׷ ̽ Ͽ / Ƽ Ǵ  .
						system($cmd_rm.' '.escapeshellarg(realpath($tmpdir.'/'.$file.'/')));
				}	// if()
			}
			closedir($dh);
		} else
		{
			errorlog("ӽ ε 丮 ۹̼ ߸Ǿ ڵ  Ͽϴ.\n=> " . $tmpdir, 'FILE');
		}	// if()
	}	// if()

	$UPLOAD_ROOT = $UPLOAD_ROOT_ORI;
}	// function()


?>
